/*
 * Copyright (c) 2018 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "DcmFaceUnittest.h"

DcmFaceUnittest::DcmFaceUnittest(void)
{
	handle = NULL;
	sourceImage = NULL;
	data = NULL;
	width = 0;
	height = 0;
	color = MM_UTIL_COLOR_RGB24;
	dataSize = 0;
	faceInfo = { NULL, 0 };
}

DcmFaceUnittest::~DcmFaceUnittest(void)
{
	if (sourceImage) {
		mm_util_destroy_handle(sourceImage);
		sourceImage = NULL;
	}

	if (faceInfo.rects) {
		free(faceInfo.rects);
		faceInfo.rects = NULL;
	}

	if (handle) {
		Deinit();
		handle = NULL;
	}
}

int DcmFaceUnittest::Init(void)
{
	return dcm_face_create(&handle);
}

int DcmFaceUnittest::Deinit(void)
{
	int ret = dcm_face_destroy(handle);

	handle = NULL;

	return ret;
}

int DcmFaceUnittest::DecodeImage(const char *path)
{
	int ret = MS_MEDIA_ERR_NONE;

	ret = mm_util_rotate_P_B(path, MM_UTIL_ROTATE_0, MM_UTIL_COLOR_RGB24, &sourceImage);
	if (ret != MS_MEDIA_ERR_NONE) {
		return ret;
	}

	return mm_util_get_image(sourceImage, &data, &width, &height, &dataSize, &color);
}

int DcmFaceUnittest::SetImageInfo(const char *path)
{
	int ret = MS_MEDIA_ERR_NONE;

	ret = DecodeImage(path);
	if (ret != MS_MEDIA_ERR_NONE) {
		return ret;
	}

	return dcm_face_set_image_info(handle, FACE_IMAGE_COLORSPACE_RGB888, data, width, height, dataSize);
}

int DcmFaceUnittest::GetFaceInfo(void)
{
	return dcm_face_get_face_info(handle, &faceInfo);
}
