/*
 * Copyright (c) 2018 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <media-util.h>
#include <tzplatform_config.h>

#include "dcm_service_unittest.h"
#include "DcmFaceUnittest.h"

#define TEST_FILE_PATH	tzplatform_mkpath(TZ_SYS_BIN, "dcm-service-unittest.jpg")

using ::testing::InitGoogleTest;
using ::testing::Test;
using ::testing::TestCase;

class dcm_service_Test : public ::testing::Test {
	protected:
		void SetUp() {
			std::cout << "SetUp()" << std::endl;
		}

		void TearDown() {
			std::cout << "TearDown()" << std::endl;
		}
};

TEST(dcm_service_Test, dcm_face_create_p)
{
	int ret = MS_MEDIA_ERR_NONE;
	DcmFaceUnittest dcmFace;

	ret = dcmFace.Init();
	EXPECT_EQ(ret, MS_MEDIA_ERR_NONE);
}

TEST(dcm_service_Test, dcm_face_destroy_p)
{
	int ret = MS_MEDIA_ERR_NONE;
	DcmFaceUnittest dcmFace;

	ret = dcmFace.Init();
	EXPECT_EQ(ret, MS_MEDIA_ERR_NONE);

	ret = dcmFace.Deinit();
	EXPECT_EQ(ret, MS_MEDIA_ERR_NONE);
}

TEST(dcm_service_Test, dcm_face_set_image_info_p)
{
	int ret = MS_MEDIA_ERR_NONE;
	DcmFaceUnittest dcmFace;

	ret = dcmFace.Init();
	EXPECT_EQ(ret, MS_MEDIA_ERR_NONE);

	ret = dcmFace.SetImageInfo(TEST_FILE_PATH);
	EXPECT_EQ(ret, MS_MEDIA_ERR_NONE);
	EXPECT_TRUE(dcmFace.data != NULL);
	EXPECT_NE(dcmFace.width, 0);
	EXPECT_NE(dcmFace.height, 0);
	EXPECT_EQ(dcmFace.color, MM_UTIL_COLOR_RGB24);
	EXPECT_NE(dcmFace.dataSize, 0);
}

TEST(dcm_service_Test, dcm_face_get_face_info_p)
{
	int ret = MS_MEDIA_ERR_NONE;
	DcmFaceUnittest dcmFace;

	ret = dcmFace.Init();
	EXPECT_EQ(ret, MS_MEDIA_ERR_NONE);

	ret = dcmFace.SetImageInfo(TEST_FILE_PATH);
	EXPECT_EQ(ret, MS_MEDIA_ERR_NONE);

	ret = dcmFace.GetFaceInfo();
	EXPECT_EQ(ret, MS_MEDIA_ERR_NONE);
	EXPECT_EQ(dcmFace.faceInfo.count, 0);
	if (dcmFace.faceInfo.count != 0)
		EXPECT_TRUE(dcmFace.faceInfo.rects != NULL);
}

int main(int argc, char **argv)
{
	InitGoogleTest(&argc, argv);

	return RUN_ALL_TESTS();
}
